@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cryptonite
-version: 0.13
-id: cryptonite-0.13-349d06636b05d6ecd7f57ca79abfe077
-key: crypt_8tOVQjMArS579icds1NXMc
+version: 0.15
+id: cryptonite-0.15-52f487cbd51518538a9e7cbc4eddf82b
+key: crypt_CcjcowokjyFJ3PzxfpgObb
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: vincent@snarc.org
@@ -40,7 +40,7 @@ exposed-modules:
     Crypto.Cipher.ChaCha Crypto.Cipher.ChaChaPoly1305 Crypto.Cipher.DES
     Crypto.Cipher.RC4 Crypto.Cipher.Salsa Crypto.Cipher.TripleDES
     Crypto.Cipher.Types Crypto.Data.AFIS Crypto.Data.Padding
-    Crypto.Error Crypto.MAC.Poly1305 Crypto.MAC.HMAC
+    Crypto.Error Crypto.MAC.CMAC Crypto.MAC.Poly1305 Crypto.MAC.HMAC
     Crypto.Number.Basic Crypto.Number.F2m Crypto.Number.Generate
     Crypto.Number.ModArithmetic Crypto.Number.Prime
     Crypto.Number.Serialize Crypto.Number.Serialize.Internal
@@ -79,17 +79,17 @@ hidden-modules: Crypto.Cipher.AES.Primitive
                 Crypto.Internal.Words Crypto.Internal.WordArray
                 Crypto.Random.Entropy.Unix
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/cryptonite-0.13
-library-dirs: /usr/lib/ghc-7.10.3/site-local/cryptonite-0.13
-data-dir: /usr/share/arm-linux-ghc-7.10.3/cryptonite-0.13
-hs-libraries: HScryptonite-0.13-8tOVQjMArS579icds1NXMc
+import-dirs: /usr/lib/ghc-7.10.3/site-local/cryptonite-0.15
+library-dirs: /usr/lib/ghc-7.10.3/site-local/cryptonite-0.15
+data-dir: /usr/share/arm-linux-ghc-7.10.3/cryptonite-0.15
+hs-libraries: HScryptonite-0.15-CcjcowokjyFJ3PzxfpgObb
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
     integer-gmp-1.0.0.0-4ff98693d6e5d6065e60052264067c09
-    memory-0.11-3a745e41fe78387f608c420e9b455d25
+    memory-0.12-092368f288b8a5ed89de3a4f849c43f2
 haddock-interfaces: /usr/share/doc/haskell-cryptonite/html/cryptonite.haddock
 haddock-html: /usr/share/doc/haskell-cryptonite/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
